#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>

using namespace std;

struct node{
    int l, r;
    vector <int> x;
    vector <int> tll, tlm;
    vector <int> trl, trm;
};

const int N = 4e5 + 5;

vector < pair <int, int> > p;
node t[N];

void build(int i, int l, int r) {
    t[i].l = l; t[i].r = r;
    if (l + 1 == r) {
        t[i].x.push_back(p[l].second);
        return;
    }
    int m = (l + r) / 2;
    build(2 * i, l, m);
    build(2 * i + 1, m, r);
    int l1 = m - l, l2 = r - m;
    t[i].x.resize(l1 + l2);
    t[i].tll.resize(l1 + l2);
    t[i].tlm.resize(l1 + l2);
    t[i].trl.resize(l2 + l1);
    t[i].trm.resize(l2 + l1);
    merge(t[2 * i].x.begin(), t[2 * i].x.end(),
          t[2 * i + 1].x.begin(), t[2 * i + 1].x.end(),
          t[i].x.begin());
    int ind1 = 0, ind2 = 0;
    for (int j = 0; j < l1 + l2; ++j) {
        while (ind1 < l1 && t[2 * i].x[ind1] <= t[i].x[j]) {
            ind1++;
        }
        t[i].tll[j] = ind1 - 1;
        while (ind2 < l2 && t[2 * i + 1].x[ind2] <= t[i].x[j]) {
            ind2++;
        }
        t[i].trl[j] = ind2 - 1;
    }
    ind1 = l1 - 1; ind2 = l2 - 1;
    for (int j = l1 + l2 - 1; j >= 0; --j) {
        while (ind1 >= 0 && t[2 * i].x[ind1] >= t[i].x[j]) {
            ind1--;
        }
        t[i].tlm[j] = ind1 + 1;
        while (ind2 >= 0 && t[2 * i + 1].x[ind2] >= t[i].x[j]) {
            ind2--;
        }
        t[i].trm[j] = ind2 + 1;
    }
}

int get_an(int i, int l, int r, int ind1, int ind2) {
    if (l >= t[i].r || r <= t[i].l || ind1 > ind2) {
        return 0;
    }
    if (l <= t[i].l && t[i].r <= r) {
        return ind2 - ind1 + 1;
    }
    int f = get_an(2 * i, l, r, t[i].tlm[ind1], t[i].tll[ind2]);
    int s = get_an(2 * i + 1, l, r, t[i].trm[ind1], t[i].trl[ind2]);
    return f + s;
}

int get_seg(int l, int r, int a, int b) {
    int ind1 = lower_bound(t[1].x.begin(), t[1].x.end(), a) - t[1].x.begin();
    int ind2 = upper_bound(t[1].x.begin(), t[1].x.end(), b) - t[1].x.begin() - 1;
    return get_an(1, l, r, ind1, ind2);
}

struct nnode{
    int l, r;
    int d, m;
};

const int NN = (1 << 18) + 5;

nnode tt[NN];

void ppush(int i) {
    tt[2 * i].d += tt[i].d;
    tt[2 * i + 1].d += tt[i].d;
    tt[i].d = 0;
}

void cchange(int i) {
    tt[i].m = max(tt[2 * i].m + tt[2 * i].d, tt[2 * i + 1].d + tt[2 * i + 1].m);
}

void bbuild(int i, int l, int r) {
    tt[i].l = l; tt[i].r = r;
    tt[i].d = 0; tt[i].m = 0;
    if (l + 1 == r) {
        return;
    }
    bbuild(2 * i, l, (l + r) / 2);
    bbuild(2 * i + 1, (l + r) / 2, r);
}

void uupdate(int i, int l, int r, int x) {
    if (l <= tt[i].l && tt[i].r <= r) {
        tt[i].d += x;
        return;
    }
    if (l >= tt[i].r || r <= tt[i].l) {
        return;
    }
    ppush(i);
    uupdate(2 * i, l, r, x);
    uupdate(2 * i + 1, l, r, x);
    cchange(i);
}

signed main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);
    int n; cin >> n;
    int w, h; cin >> w >> h;
    p.resize(n);
    int mx = 0, my = 0;
    for (int i = 0; i < n; ++i) {
        cin >> p[i].first >> p[i].second;
        mx = max(mx, p[i].first);
        my = max(my, p[i].second);
    }
    sort(p.begin(), p.end());
    if (mx <= 1e5 && my <= 1e5 && h <= 1e5 && w <= 1e5) {
        bbuild(1, 0, (1 << 17));
        int ind = 0;
        int an = 0;
        for (int i = 0; i < n; ++i) {
            uupdate(1, max(p[i].second - h + 1, 0), p[i].second + 1, 1);
            while (p[i].first - p[ind].first > w) {
                uupdate(1, max(p[ind].second - h + 1, 0), p[ind].second + 1, -1);
                ind++;
            }
            an = max(an, tt[1].m);
        }
        cout << an << "\n";
        return 0;
    }
    build(1, 0, n);
    int an = 0;
    for (int i = 0; i < n; ++i) {
        int L = -1, R = i;
        while (R - L > 1) {
            int M = (R + L) / 2;
            if (p[M].first >= p[i].first - w) {
                R = M;
            } else {
                L = M;
            }
        }
        an = max(an, get_seg(R, i + 1, p[i].second - h, p[i].second));
    }
    if (n <= 1000) {
        for (int i = 0; i < n; ++i) {
            for (int j = i + 1; j < n; ++j) {
                if (p[i].second > p[j].second && p[j].first > p[i].first && p[i].second - p[j].second <= h && p[j].first - p[i].first <= w) {
                    int L = -1, R = j;
                    while (R - L > 1) {
                        int M = (R + L) / 2;
                        if (p[M].first >= p[j].first - w) {
                            R = M;
                        } else {
                            L = M;
                        }
                    }
                    an = max(an, get_seg(R, j + 1, p[i].second - h, p[i].second));
                }
            }
        }
    }
    cout << an << "\n";
    return 0;
}
